# 26/8/2020

# Antti Miettinen, Stefan Palm, Johan Dannewitz, Emma Lind, Craig R. Primmer, Atso Romakkaniemi, Johan stergren, Victoria L. Pritchard

# Article: "A large wild salmon stock shows genetic and life history differentiation within, but not between, rivers" 
# email: Antti Miettinen (antti.aj.miettinen@helsinki.fi)

setwd("File path")
#Such as:
#setwd(".../TornioKalix_Msat_Dryad/TornioKalix_Msat_Data/Data for R")

### R CODE FOR SUPPLEMENTARY MATERIAL

# 1) Code below is for making Supplementary Figures S5a to S6d (Online resource 4)

#Read the Tornio-Kalix baseline parr data file.
Reference_parr  = read.table ("Reference_parr_TK_for_Rubias.txt", header=T, skipNul=T)
#This is parr from all Tornio-Kalix collection sites. 

Reference_parr$repunit <- as.character(Reference_parr$repunit)
Reference_parr$collection <- as.character(Reference_parr$collection)
Reference_parr$indiv <- as.character(Reference_parr$indiv)
Reference_parr$sample_type = as.character (Reference_parr$sample_type)

#######
#Smolts
#Whole season condensed

#Packages needed
library(rubias)
library(tidyverse)

Smolts_wholeseason  = read.table ("Smolts_TK_for_Rubias_noweeks.txt", header=T, skipNul=T)
#This is the smolt data with no weeks split

Smolts_wholeseason$repunit = as.character (Smolts_wholeseason$repunit)
Smolts_wholeseason$collection = as.character (Smolts_wholeseason$collection)
Smolts_wholeseason$indiv = as.character (Smolts_wholeseason$indiv)
Smolts_wholeseason$sample_type = as.character (Smolts_wholeseason$sample_type)

smolts_mix_est_wholeseason <- infer_mixture(reference = Reference_parr, mixture = Smolts_wholeseason, gen_start_col = 5)

#Traces for the whole season condensed
trace_smolts_wholeseason <- smolts_mix_est_wholeseason$mix_prop_traces %>% filter(sweep > 200) %>% 
  group_by(sweep, repunit) %>% summarise(repprop = sum(pi))


#Package needed:

library(ggplot2)

smoltsplot_wholeseason = ggplot(trace_smolts_wholeseason, aes(x=repunit, y=repprop, fill=repunit))

smoltsplot_box_repunit <- smoltsplot_wholeseason + geom_boxplot(outlier.size=0.95, alpha=0.8) + theme_classic() + 
  labs(title="Smolts 2011", x="Reporting group", y="Mixture proportion", fill="Reporting group") + 
  theme(legend.position="none") + scale_fill_manual(values = c("#62ddbe", "#3949ac"))

smoltsplot_box_repunit


###The figure below is smolts with split weeks

Smolts_rubias = read.table ("Smolts_TK_for_Rubias.txt", header=T, skipNul=T)

Smolts_rubias$repunit = as.character (Smolts_rubias$repunit)
Smolts_rubias$collection = as.character (Smolts_rubias$collection)
Smolts_rubias$indiv = as.character (Smolts_rubias$indiv)
Smolts_rubias$sample_type = as.character (Smolts_rubias$sample_type)

smolts_mix_est <- infer_mixture(reference = Reference_parr, mixture = Smolts_rubias, gen_start_col = 5)

trace_smolts_W1 <- smolts_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week1", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_smolts_W2 <- smolts_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week2", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_smolts_W3 <- smolts_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week3", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_smolts_W4 <- smolts_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week4", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_smolts_W5 <- smolts_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week5", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_smolts_W6 <- smolts_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week6", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))

trace_smolts_W1$Week = "Week 1"
trace_smolts_W2$Week = "Week 2"
trace_smolts_W3$Week = "Week 3"
trace_smolts_W4$Week = "Week 4"
trace_smolts_W5$Week = "Week 5"
trace_smolts_W6$Week = "Week 6"

trace_smolts_W1_2 = bind_rows(trace_smolts_W1)
trace_smolts_W3_4 = bind_rows(trace_smolts_W2)
trace_smolts_W5_6 = bind_rows(trace_smolts_W3)
trace_smolts_W7_8 = bind_rows(trace_smolts_W4)
trace_smolts_W9_10 = bind_rows(trace_smolts_W5)

trace_smolts_allweeks = bind_rows (trace_smolts_W1, trace_smolts_W2, trace_smolts_W3, trace_smolts_W4, trace_smolts_W5, trace_smolts_W6)

smoltsplot_weeks = ggplot(trace_smolts_allweeks, aes(x=repunit, y=repprop, fill=repunit))

smoltsplot_weeks_box_repunit = smoltsplot_weeks + geom_boxplot(outlier.size=0.95, alpha=0.8) + theme_classic() + 
  labs(title="Smolts 2011", x="Reporting group", y="Mixture proportion", fill="Reporting group") + 
  theme(legend.position="none") + facet_grid(Week ~ .) + scale_fill_manual(values = c("#62ddbe", "#3949ac"))

smoltsplot_weeks_box_repunit


######

#Adults

###
#Adults 2009
#Whole season condensed

Adults09_wholeseason  = read.table ("Adults2009_TK_for_Rubias_noweeks.txt", header=T, skipNul=T)
#This is with no weeks split

Adults09_wholeseason$repunit = as.character (Adults09_wholeseason$repunit)
Adults09_wholeseason$collection = as.character (Adults09_wholeseason$collection)
Adults09_wholeseason$indiv = as.character (Adults09_wholeseason$indiv)
Adults09_wholeseason$sample_type = as.character (Adults09_wholeseason$sample_type)

adults09_mix_est_wholeseason <- infer_mixture(reference = Reference_parr, mixture = Adults09_wholeseason, gen_start_col = 5)

#For the whole season condensed
trace_adults09_wholeseason <- adults09_mix_est_wholeseason$mix_prop_traces %>% filter(sweep > 200) %>% 
  group_by(sweep, repunit) %>% summarise(repprop = sum(pi))

adults09plot_wholeseason = ggplot(trace_adults09_wholeseason, aes(x=repunit, y=repprop, fill=repunit))

adults09plot_box_repunit = adults09plot_wholeseason + geom_boxplot(outlier.size=0.95, alpha=0.8) + theme_classic() + 
  labs(title="Adults 2009", x="Reporting group", y="Mixture proportion", fill="Reporting group") + 
  theme(legend.position="none") + scale_fill_manual(values = c("#62ddbe", "#3949ac"))

adults09plot_box_repunit


###The figure below is adults 2009 with split weeks

Adults09_rubias = read.table ("Adults2009_TK_for_Rubias.txt", header=T, skipNul=T)

Adults09_rubias$repunit = as.character (Adults09_rubias$repunit)
Adults09_rubias$collection = as.character (Adults09_rubias$collection)
Adults09_rubias$indiv = as.character (Adults09_rubias$indiv)
Adults09_rubias$sample_type = as.character (Adults09_rubias$sample_type)

adults09_mix_est <- infer_mixture(reference = Reference_parr, mixture = Adults09_rubias, gen_start_col = 5)

trace_adults09_W1 <- adults09_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week1_2", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults09_W2 <- adults09_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week3_4", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults09_W3 <- adults09_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week5_6", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults09_W4 <- adults09_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week7_8", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults09_W5 <- adults09_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week9_10", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))

trace_adults09_W1$Week = "Weeks 1-2"
trace_adults09_W2$Week = "Weeks 3-4"
trace_adults09_W3$Week = "Weeks 5-6"
trace_adults09_W4$Week = "Weeks 7-8"
trace_adults09_W5$Week = "Weeks 9-10"

trace_adults09_W1_2 = bind_rows(trace_adults09_W1)
trace_adults09_W3_4 = bind_rows(trace_adults09_W2)
trace_adults09_W5_6 = bind_rows(trace_adults09_W3)
trace_adults09_W7_8 = bind_rows(trace_adults09_W4)
trace_adults09_W9_10 = bind_rows(trace_adults09_W5)

trace_adults09_allweeks = bind_rows (trace_adults09_W1, trace_adults09_W2, trace_adults09_W3, trace_adults09_W4, trace_adults09_W5)

adults09plot_weeks = ggplot(trace_adults09_allweeks, aes(x=repunit, y=repprop, fill=repunit))

adults09plot_weeks_box_repunit = adults09plot_weeks + geom_boxplot(outlier.size=0.95, alpha=0.8) + theme_classic() + 
  labs(title="Adults 2009", x="Reporting group", y="Mixture proportion", fill="Reporting group") + 
  theme(legend.position="none") + facet_grid(Week ~ .) + scale_fill_manual(values = c("#62ddbe", "#3949ac"))

adults09plot_weeks_box_repunit


###

# Adults 2010

Adults10_wholeseason  = read.table ("Adults2010_TK_for_Rubias_noweeks.txt", header=T, skipNul=T)
#This is with no weeks split

Adults10_wholeseason$repunit = as.character (Adults10_wholeseason$repunit)
Adults10_wholeseason$collection = as.character (Adults10_wholeseason$collection)
Adults10_wholeseason$indiv = as.character (Adults10_wholeseason$indiv)
Adults10_wholeseason$sample_type = as.character (Adults10_wholeseason$sample_type)

adults10_mix_est_wholeseason <- infer_mixture(reference = Reference_parr, mixture = Adults10_wholeseason, gen_start_col = 5)

#For the whole season condensed
trace_adults10_wholeseason <- adults10_mix_est_wholeseason$mix_prop_traces %>% filter(sweep > 200) %>% 
  group_by(sweep, repunit) %>% summarise(repprop = sum(pi))

adults10plot_wholeseason = ggplot(trace_adults10_wholeseason, aes(x=repunit, y=repprop, fill=repunit))

adults10plot_box_repunit = adults10plot_wholeseason + geom_boxplot(outlier.size=0.95, alpha=0.8) + theme_classic() + 
  labs(title="Adults 2010", x="Reporting group", y="Mixture proportion", fill="Reporting group") + 
  theme(legend.position="none") + scale_fill_manual(values = c("#62ddbe", "#3949ac"))

adults10plot_box_repunit


###The figure below is adults 2010 with split weeks

Adults10_rubias = read.table ("Adults2010_TK_for_Rubias.txt", header=T, skipNul=T)

Adults10_rubias$repunit = as.character (Adults10_rubias$repunit)
Adults10_rubias$collection = as.character (Adults10_rubias$collection)
Adults10_rubias$indiv = as.character (Adults10_rubias$indiv)
Adults10_rubias$sample_type = as.character (Adults10_rubias$sample_type)

adults10_mix_est <- infer_mixture(reference = Reference_parr, mixture = Adults10_rubias, gen_start_col = 5)

trace_adults10_W1 <- adults10_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week1_2", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults10_W2 <- adults10_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week3_4", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults10_W3 <- adults10_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week5_6", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults10_W4 <- adults10_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week7_8", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
trace_adults10_W5 <- adults10_mix_est$mix_prop_traces %>% 
  filter(mixture_collection == "Week9_10", sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))

trace_adults10_W1$Week = "Weeks 1-2"
trace_adults10_W2$Week = "Weeks 3-4"
trace_adults10_W3$Week = "Weeks 5-6"
trace_adults10_W4$Week = "Weeks 7-8"
trace_adults10_W5$Week = "Weeks 9-10"

trace_adults10_W1_2 = bind_rows(trace_adults10_W1)
trace_adults10_W3_4 = bind_rows(trace_adults10_W2)
trace_adults10_W5_6 = bind_rows(trace_adults10_W3)
trace_adults10_W7_8 = bind_rows(trace_adults10_W4)
trace_adults10_W9_10 = bind_rows(trace_adults10_W5)

trace_adults10_allweeks = bind_rows (trace_adults10_W1, trace_adults10_W2, trace_adults10_W3, trace_adults10_W4, trace_adults10_W5)

adults10plot_weeks = ggplot(trace_adults10_allweeks, aes(x=repunit, y=repprop, fill=repunit))

adults10plot_weeks_box_repunit = adults10plot_weeks + geom_boxplot(outlier.size=0.95, alpha=0.8) + theme_classic() + 
  labs(title="Adults 2010", x="Reporting group", y="Mixture proportion", fill="Reporting group") + 
  theme(legend.position="none") + facet_grid(Week ~ .) + scale_fill_manual(values = c("#62ddbe", "#3949ac"))

adults10plot_weeks_box_repunit



# The code below is for making Supplementary Figures S6a and S6b (Online resource 4)

#Package needed:

library(ggplot2)

col = c("Female"="#E66100", "Male" = "#5D3A9B", "Unknown" = "gray50")
smoltlabels = c("2" = "2 years old", "3" = "3 years old", "4+" = "4-5 years old")
labels = c("1" = "1 sea winter", "2" = "2 sea winters", "3" = "3 sea winters", 
           "4+" = "4-5 sea winters", "PS" = "Repeat spawners")



smolts = read.table ("Data_Smolts_TK.txt", header=T)
smoltplot <- ggplot (smolts, aes (x=DAY, y= PofZU, group = SMOLT.AGE, colour = SEX))
smoltplot <- smoltplot + geom_point (size=2.5, alpha=0.5) 
smoltplot <- smoltplot + facet_grid (SMOLT.AGE ~ ., labeller=labeller(SMOLT.AGE = smoltlabels)) 
smoltplot <- smoltplot + theme_bw() 
smoltplot <- smoltplot + theme(panel.grid.minor = element_blank(), panel.grid.major = element_blank()) 
smoltplot <- smoltplot + xlab ("Arrival in smolt trap") + ylab ("P(Upper)") 
smoltplot <- smoltplot + scale_colour_manual (values = col) 
smoltplot <- smoltplot + theme(legend.text=element_text(size=11))
smoltplot <- smoltplot + labs(title="Outmigrating smolts") + guides(color=guide_legend("Sex"))
smoltplot

#ggsave (file = "Dataplot_Smolts_TK.jpeg", height = 8, width = 6.5, unit = "in")


adults = read.table ("Data_Adults_TK.txt", header=T)
adultplot = ggplot (data=adults, 
                    aes (x=DAY, y= PofZU, group = SEA.AGE, colour = SEX))
adultplot <- adultplot + geom_point (size=2.5, alpha=0.5) 
adultplot <- adultplot + facet_grid (SEA.AGE ~ YEAR, labeller=labeller(SEA.AGE = labels)) 
adultplot <- adultplot + theme_bw() + guides(color=guide_legend("Sex"))
adultplot <- adultplot + theme(panel.grid.minor = element_blank(), panel.grid.major = element_blank()) 
adultplot <- adultplot + xlab ("Capture date") + ylab ("P(Upper)") 
adultplot <- adultplot + labs(title="Returning adults") + scale_fill_discrete(name="Sex")
adultplot <- adultplot + scale_colour_manual (values = col) + theme(legend.text=element_text(size=11))
adultplot

#ggsave (file = "Dataplot_Adults_TK.jpeg", height = 8, width = 6.5, unit = "in")
